#include "ql_oracle.cpp"
#include "QC_AQMessage.cpp"
#include "QC_AQQueue.cpp"
#include "oracle.cpp"
#include "oracleobject.cpp"
#include "QoreOracleConnection.cpp"
#include "QoreOracleStatement.cpp"
#include "QorePreparedStatement.cpp"
#include "OraColumnValue.cpp"
#include "OraResultSet.cpp"
#include "ocilib/exception.cpp"
#include "ocilib/string.cpp"
#include "ocilib/timestamp.cpp"
#include "ocilib/collection.cpp"
#include "ocilib/element.cpp"
#include "ocilib/library.cpp"
#include "ocilib/number.cpp"
#include "ocilib/typeinfo.cpp"
#include "ocilib/column.cpp"
#include "ocilib/error.cpp"
#include "ocilib/list.cpp"
#include "ocilib/memory.cpp"
#include "ocilib/lob.cpp"
#include "ocilib/object.cpp"
#include "ocilib/interval.cpp"
#include "ocilib/date.cpp"
#include "ocilib/connection.cpp"
#include "ocilib/msg.cpp"
#include "ocilib/enqueue.cpp"
#include "ocilib/dequeue.cpp"
#include "ocilib/agent.cpp"
#include "ocilib/callback.cpp"

